/*

  Nokia 6100 Display Test
  Copyright 2006 Refik Hadzialic (http://www.e-dsp.com) but this code
  was derived from Thomas Pfeifer's code at
  http://thomaspfeifer.net/nokia_6100_display.htm and Owen Osborn's code
  at http://www.sparkfun.com/datasheets/LCD/Nokia6100_Demo.c. I don't 
  the credits for it. 


  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


  Target: AVR-ATMega32
  Compiler: AVRGcc

  Note: 

*/

//#### CONFIG ####
#define SPIPORT PORTC
#define SPIDDR DDRC
#define CS 3
#define CLK 2
#define SDA 1
#define RESET 0



//#################
//#include <util/delay.h>

#define cbi(reg, bit) (reg&=~(1<<bit))
#define sbi(reg, bit) (reg|= (1<<bit))

#define CS0 cbi(SPIPORT,CS);
#define CS1 sbi(SPIPORT,CS);
#define CLK0 cbi(SPIPORT,CLK);
#define CLK1 sbi(SPIPORT,CLK);
#define SDA0 cbi(SPIPORT,SDA);
#define SDA1 sbi(SPIPORT,SDA);
#define RESET0 cbi(SPIPORT,RESET);
#define RESET1 sbi(SPIPORT,RESET);

#define DISON   0xAF    // Display on
#define DISOFF  0xAE    // Display off
#define DISNOR  0xA6    // Normal display
#define DISINV  0xA7    // Inverse display
#define COMSCN  0xBB    // Common scan direction
#define DISCTL  0xCA    // Display control
#define SLPIN   0x95    // Sleep in
#define SLPOUT  0x94    // Sleep out
#define PASET   0x75    // Page address set
#define CASET   0x15    // Column address set
#define DATCTL  0xBC    // Data scan direction, etc.
#define RGBSET8 0xCE    // 256-color position set
#define RAMWR   0x5C    // Writing to memory
#define RAMRD   0x5D    // Reading from memory
#define PTLIN   0xA8    // Partial display in
#define PTLOUT  0xA9    // Partial display out
#define RMWIN   0xE0    // Read and modify write
#define RMWOUT  0xEE    // End
#define ASCSET  0xAA    // Area scroll set
#define SCSTART 0xAB    // Scroll start set
#define OSCON   0xD1    // Internal oscillation on
#define OSCOFF  0xD2    // Internal oscillation off
#define PWRCTR  0x20    // Power control
#define VOLCTR  0x81    // Electronic volume control
#define VOLUP   0xD6    // Increment electronic control by 1
#define VOLDOWN 0xD7    // Decrement electronic control by 1
#define TMPGRD  0x82    // Temperature gradient set
#define EPCTIN  0xCD    // Control EEPROM
#define EPCOUT  0xCC    // Cancel EEPROM control
#define EPMWR   0xFC    // Write into EEPROM
#define EPMRD   0xFD    // Read from EEPROM
#define EPSRRD1 0x7C    // Read register 1
#define EPSRRD2 0x7D    // Read register 2
#define NOP     0x25    // NOP instruction

#define byte unsigned char
byte n=0;
byte s1,s2;
byte r,g,b;

void lcdInit(void);
void sendCMD(byte cmd);
void sendData(byte cmd);
void shiftBits(byte b);
void LCD_put_pixel(byte r, byte g, byte b, byte x, byte y);
void LCD_put_bitmap(unsigned int *bitmap, byte x, byte y, byte width, byte height);
void LCD_put_bitmapf(unsigned int *bitmap, byte x, byte y, byte width, byte height);
void LCD_draw_box(byte x, byte y, byte width, byte height, unsigned int color);
void LCD_put_str(char *str, unsigned int color_fg, unsigned int color_bg, byte x, byte y);
void LCD_put_char(byte c, unsigned int color_fg, unsigned int color_bg, byte x, byte y);
void setDrawingArea(byte x, byte y, byte width, byte height);

#include "lcd_font.h"
#include "lcdLib.c"
